import { Box, Button, TableRow, Typography } from '@mui/material'
import ConfirmDialog from 'components/confirmDialog'
import { Identity } from 'interfaces'
import { useState } from 'react'
import { submitJsonOpts } from 'utils'
import CheckIcon from '@mui/icons-material/Check'
import { useTranslation } from 'react-i18next'
import { TableCell } from 'components/table'
import { appInst, disableNinVerification } from 'appConfig'

interface IdentityLineProps {
  text: string
  identity: Identity | null
  reloadGuest: () => void
  reloadGuests: () => void
}

const IdentityLine = ({
  text,
  identity,
  reloadGuest,
  reloadGuests,
}: IdentityLineProps) => {
  // Make a line with a confirmation button if the identity has not been verified
  const [confirmOpen, setConfirmOpen] = useState(false)
  const [t] = useTranslation('common')
  const verifyIdentity = (id: string) => async () => {
    await fetch(`/api/ui/v1/identity/${id}`, submitJsonOpts('PATCH', {}))
    reloadGuest()
    reloadGuests()
  }

  if (identity == null) {
    return <></>
  }
  const getDialogText = () => {
    switch (appInst) {
      case 'uio':
        return t('confirmationDialog.text.uio')
      case 'uib':
        return t('confirmationDialog.text.uib')
      default:
        return t('confirmationDialog.text.default')
    }
  }
  return (
    <TableRow>
      <TableCell align="left">{text}</TableCell>
      <TableCell align="left">
        <Box
          sx={{
            display: 'flex',
            flexDirection: { xs: 'column', md: 'row' },
            justifyContent: 'flex-start',
          }}
        >
          {/* Setting flex grow to 1 to push the verify button to the right on large screens */}
          <Box
            sx={{
              flexGrow: 1,
            }}
          >
            {identity ? identity.value : ''}
          </Box>

          {!identity.verified_at ? (
            <Box>
              <Typography>
                <Button
                  aria-label={t('button.verify')}
                  sx={{
                    alignSelf: { xs: 'auto', md: 'flex-end' },
                    marginLeft: { xs: '0rem', md: '1rem' },
                    marginTop: { xs: '0.3rem', md: '0rem' },
                  }}
                  onClick={() => setConfirmOpen(true)}
                  disabled={
                    !identity ||
                    (disableNinVerification &&
                      identity.type === 'norwegian_national_id_number')
                  }
                >
                  {t('button.verify')}
                </Button>
                <ConfirmDialog
                  title={t('confirmationDialog.confirmIdentityTitle')}
                  open={confirmOpen}
                  setOpen={setConfirmOpen}
                  onConfirm={verifyIdentity(identity.id)}
                >
                  {getDialogText()}
                </ConfirmDialog>
              </Typography>
            </Box>
          ) : (
            <CheckIcon sx={{ fill: (theme) => theme.palette.success.main }} />
          )}
        </Box>
      </TableCell>
    </TableRow>
  )
}

export default IdentityLine
